==> kwap-0.3.4.crate: kwap-0.3.4/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### 0.3.4 (2022-01-29)

### 0.3.3 (2022-01-29)


### Features

* **kwap:** add platformless blocking::Client::new and Config struct ([#60](https://github.com/clov-coffee/kwap/issues/60)) ([45c6a65](https://github.com/clov-coffee/kwap/commit/45c6a65b72709d5ad37d042353e45c891ef88fc7))

### 0.3.2 (2022-01-28)

### 0.3.1 (2022-01-22)

## 0.3.0 (2022-01-15)


### ⚠ BREAKING CHANGES

* **kwap:** we should retry sending CONfirmable messages until ACKed (#56)

### Features

* **kwap:** we should retry sending CONfirmable messages until ACKed ([#56](https://github.com/clov-coffee/kwap/issues/56)) ([7de512d](https://github.com/clov-coffee/kwap/commit/7de512dcb8ed4e24b9a725bb4add9d175864aab7))

## 0.2.0 (2022-01-15)


### ⚠ BREAKING CHANGES

* **kwap:** remove interior mutability in Core (#55)

### Bug Fixes

* **kwap:** remove interior mutability in Core ([#55](https://github.com/clov-coffee/kwap/issues/55)) ([768f4b9](https://github.com/clov-coffee/kwap/commit/768f4b94c078958f54e18efa53d93ce1ab144182))

### 0.1.10 (2022-01-12)


### Features

* **kwap:** core should allow pinging coap servers ([#53](https://github.com/clov-coffee/kwap/issues/53)) ([de7cfda](https://github.com/clov-coffee/kwap/commit/de7cfda186b47ad1a41da2f9da922ceb2ea5e1ed))

### 0.1.9 (2022-01-11)

### 0.1.8 (2022-01-11)


### Bug Fixes

* **kwap:** add error types to send_req ([#50](https://github.com/clov-coffee/kwap/issues/50)) ([818904a](https://github.com/clov-coffee/kwap/commit/818904a039b3e7884d3411bc2cd0462f4f3f56a6))

### 0.1.7 (2022-01-11)

### 0.1.6 (2022-01-08)

### 0.1.5 (2022-01-08)


### Bug Fixes

* **kwap:** client should work ([#46](https://github.com/clov-coffee/kwap/issues/46)) ([0e8058c](https://github.com/clov-coffee/kwap/commit/0e8058c4e8a9828339e8c6d89e015f9a85c24242))

### 0.1.4 (2022-01-07)


### Features

* **kwap:** runtime should support acting as client ([#45](https://github.com/clov-coffee/kwap/issues/45)) ([0d63c52](https://github.com/clov-coffee/kwap/commit/0d63c52fa872e7a33ac7b298ae55e75870c1a147))

### 0.1.3 (2022-01-07)


### Features

* **kwap:** initial commit of client ([#43](https://github.com/clov-coffee/kwap/issues/43)) ([f9f13cb](https://github.com/clov-coffee/kwap/commit/f9f13cb67cc3d962c038f93a798261d8572c3fa5))

### 0.1.2 (2022-01-04)


### Features

* **kwap:** add request type ([#39](https://github.com/clov-coffee/kwap/issues/39)) ([2fb2622](https://github.com/clov-coffee/kwap/commit/2fb262260f80455e3649f99d7be763015a269b2d))

### 0.1.1 (2022-01-02)


### Features

* **kwap:** rough cut of response struct ([#31](https://github.com/clov-coffee/kwap/issues/31)) ([306f30d](https://github.com/clov-coffee/kwap/commit/306f30dbbb459cc7eae32db8b20f8d213dd23a2c))

==> kwap-0.3.5.crate: kwap-0.3.5/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### 0.3.5 (2022-02-04)


### Bug Fixes

* **kwap:** support nons that do not receive a response ([#64](https://github.com/clov-coffee/kwap/issues/64)) ([27f64f1](https://github.com/clov-coffee/kwap/commit/27f64f198dc8211d6a8d35cd5e54702f842a8da3))

### 0.3.4 (2022-01-29)

### 0.3.3 (2022-01-29)


### Features

* **kwap:** add platformless blocking::Client::new and Config struct ([#60](https://github.com/clov-coffee/kwap/issues/60)) ([45c6a65](https://github.com/clov-coffee/kwap/commit/45c6a65b72709d5ad37d042353e45c891ef88fc7))

### 0.3.2 (2022-01-28)

### 0.3.1 (2022-01-22)

## 0.3.0 (2022-01-15)


### ⚠ BREAKING CHANGES

* **kwap:** we should retry sending CONfirmable messages until ACKed (#56)

### Features

* **kwap:** we should retry sending CONfirmable messages until ACKed ([#56](https://github.com/clov-coffee/kwap/issues/56)) ([7de512d](https://github.com/clov-coffee/kwap/commit/7de512dcb8ed4e24b9a725bb4add9d175864aab7))

## 0.2.0 (2022-01-15)


### ⚠ BREAKING CHANGES

* **kwap:** remove interior mutability in Core (#55)

### Bug Fixes

* **kwap:** remove interior mutability in Core ([#55](https://github.com/clov-coffee/kwap/issues/55)) ([768f4b9](https://github.com/clov-coffee/kwap/commit/768f4b94c078958f54e18efa53d93ce1ab144182))

### 0.1.10 (2022-01-12)


### Features

* **kwap:** core should allow pinging coap servers ([#53](https://github.com/clov-coffee/kwap/issues/53)) ([de7cfda](https://github.com/clov-coffee/kwap/commit/de7cfda186b47ad1a41da2f9da922ceb2ea5e1ed))

### 0.1.9 (2022-01-11)

### 0.1.8 (2022-01-11)


### Bug Fixes

* **kwap:** add error types to send_req ([#50](https://github.com/clov-coffee/kwap/issues/50)) ([818904a](https://github.com/clov-coffee/kwap/commit/818904a039b3e7884d3411bc2cd0462f4f3f56a6))

### 0.1.7 (2022-01-11)

### 0.1.6 (2022-01-08)

### 0.1.5 (2022-01-08)


### Bug Fixes

* **kwap:** client should work ([#46](https://github.com/clov-coffee/kwap/issues/46)) ([0e8058c](https://github.com/clov-coffee/kwap/commit/0e8058c4e8a9828339e8c6d89e015f9a85c24242))

### 0.1.4 (2022-01-07)


### Features

* **kwap:** runtime should support acting as client ([#45](https://github.com/clov-coffee/kwap/issues/45)) ([0d63c52](https://github.com/clov-coffee/kwap/commit/0d63c52fa872e7a33ac7b298ae55e75870c1a147))

### 0.1.3 (2022-01-07)


### Features

* **kwap:** initial commit of client ([#43](https://github.com/clov-coffee/kwap/issues/43)) ([f9f13cb](https://github.com/clov-coffee/kwap/commit/f9f13cb67cc3d962c038f93a798261d8572c3fa5))

### 0.1.2 (2022-01-04)


### Features

* **kwap:** add request type ([#39](https://github.com/clov-coffee/kwap/issues/39)) ([2fb2622](https://github.com/clov-coffee/kwap/commit/2fb262260f80455e3649f99d7be763015a269b2d))

### 0.1.1 (2022-01-02)


### Features

* **kwap:** rough cut of response struct ([#31](https://github.com/clov-coffee/kwap/issues/31)) ([306f30d](https://github.com/clov-coffee/kwap/commit/306f30dbbb459cc7eae32db8b20f8d213dd23a2c))
